## add variables to global environment
utils::globalVariables(c("U1",
                         "U2",
                         "actual_slide",
                         "ad_p_value",
                         "ad_test_statistic",
                         "cluster_slide",
                         "marker",
                         "marker_threshold",
                         "misclass_error",
                         "slide_threshold",
                         "std_ad_test_statistic",
                         "level",
                         "sd",
                         "discordance_score",
                         "proportions"))
